@@ -201,6 +201,12 @@ pub enum Skill {
     Diversion,
     FireResistance,
     HornMaestro,
+    Ballistics,
+    KushalaBlessing,
+    ChameleosBlessing,
+    TeostraBlessing,
+    MastersTouch,
+    RapidFireUp,
 }
 
 use Skill::*;
@@ -224,7 +230,7 @@ impl Skill {
     pub fn get_limit(&self) -> u8 {
         self.get_skill_desc().limit
     }
-    pub const ALL: [Skill; 100] = [
+    pub const ALL: [Skill; 106] = [
         Botanist,
         DefenseBoost,
         ItemProlonger,
@@ -325,6 +331,12 @@ impl Skill {
         Diversion,
         FireResistance,
         HornMaestro,
+        Ballistics,
+        KushalaBlessing,
+        ChameleosBlessing,
+        TeostraBlessing,
+        MastersTouch,
+        RapidFireUp,
     ];
     fn get_skill_desc(&self) -> SkillDesc {
         match self {
@@ -385,7 +397,7 @@ impl Skill {
 
             ProtectivePolish => SkillDesc {
                 limit: 3,
-                jewel_size: None,
+                jewel_size: Some(2),
             },
 
             StaminaThief => SkillDesc {
@@ -395,7 +407,7 @@ impl Skill {
 
             Partbreaker => SkillDesc {
                 limit: 3,
-                jewel_size: None,
+                jewel_size: Some(2),
             },
 
             Mushroomancer => SkillDesc {
@@ -440,7 +452,7 @@ impl Skill {
 
             NormalRapidUp => SkillDesc {
                 limit: 3,
-                jewel_size: None,
+                jewel_size: Some(3),
             },
 
             SpeedEating => SkillDesc {
@@ -485,7 +497,7 @@ impl Skill {
 
             PierceUp => SkillDesc {
                 limit: 3,
-                jewel_size: None,
+                jewel_size: Some(3),
             },
 
             AimBooster => SkillDesc {
@@ -495,7 +507,7 @@ impl Skill {
 
             SleepAttack => SkillDesc {
                 limit: 3,
-                jewel_size: None,
+                jewel_size: Some(2),
             },
 
             BlightResistance => SkillDesc {
@@ -510,7 +522,7 @@ impl Skill {
 
             JumpMaster => SkillDesc {
                 limit: 1,
-                jewel_size: None,
+                jewel_size: Some(3),
             },
 
             Constitution => SkillDesc {
@@ -525,17 +537,17 @@ impl Skill {
 
             GoodLuck => SkillDesc {
                 limit: 3,
-                jewel_size: None,
+                jewel_size: Some(3),
             },
 
             RazorSharp => SkillDesc {
                 limit: 3,
-                jewel_size: None,
+                jewel_size: Some(2),
             },
 
             SpareShot => SkillDesc {
                 limit: 3,
-                jewel_size: None,
+                jewel_size: Some(2),
             },
 
             WirebugWhisperer => SkillDesc {
@@ -545,12 +557,12 @@ impl Skill {
 
             Resentment => SkillDesc {
                 limit: 3,
-                jewel_size: None,
+                jewel_size: Some(2),
             },
 
             Handicraft => SkillDesc {
                 limit: 5,
-                jewel_size: None,
+                jewel_size: Some(3),
             },
 
             FlinchFree => SkillDesc {
@@ -565,17 +577,17 @@ impl Skill {
 
             LatentPower => SkillDesc {
                 limit: 5,
-                jewel_size: None,
+                jewel_size: Some(2),
             },
 
             WeaknessExploit => SkillDesc {
                 limit: 3,
-                jewel_size: None,
+                jewel_size: Some(2),
             },
 
             Resuscitate => SkillDesc {
                 limit: 3,
-                jewel_size: None,
+                jewel_size: Some(2),
             },
 
             EvadeWindow => SkillDesc {
@@ -595,7 +607,7 @@ impl Skill {
 
             Agitator => SkillDesc {
                 limit: 5,
-                jewel_size: None,
+                jewel_size: Some(2),
             },
 
             DevineBlessing => SkillDesc {
@@ -655,7 +667,7 @@ impl Skill {
 
             SpreadUp => SkillDesc {
                 limit: 3,
-                jewel_size: None,
+                jewel_size: Some(3),
             },
 
             ReloadSpeed => SkillDesc {
@@ -745,7 +757,7 @@ impl Skill {
 
             HellfireCloak => SkillDesc {
                 limit: 4,
-                jewel_size: None,
+                jewel_size: Some(3),
             },
 
             BubblyDance => SkillDesc {
@@ -780,7 +792,7 @@ impl Skill {
 
             BlastAttack => SkillDesc {
                 limit: 3,
-                jewel_size: None,
+                jewel_size: Some(2),
             },
 
             MasterMounter => SkillDesc {
@@ -827,6 +839,30 @@ impl Skill {
                 limit: 1,
                 jewel_size: Some(1),
             },
+            Ballistics => SkillDesc {
+                limit: 3,
+                jewel_size: Some(2),
+            },
+            KushalaBlessing => SkillDesc {
+                limit: 4,
+                jewel_size: None,
+            },
+            ChameleosBlessing => SkillDesc {
+                limit: 4,
+                jewel_size: None,
+            },
+            TeostraBlessing => SkillDesc {
+                limit: 4,
+                jewel_size: None,
+            },
+            MastersTouch => SkillDesc {
+                limit: 3,
+                jewel_size: Some(2),
+            },
+            RapidFireUp => SkillDesc {
+                limit: 3,
+                jewel_size: Some(3),
+            },
         }
     }
 }
